///////
   //
   //    htcheck.h
   //
   //    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
   //    Some Portions Copyright (c) 1995-2000 The ht://Dig Group <www.htdig.org>
   //    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
   //
   //    For copyright details, see the file COPYING in your distribution
   //    or the GNU General Public License version 2 or later 
   //    <http://www.gnu.org/copyleft/gpl.html>
   //
   //    $Id: htcheck.h,v 1.7 2003/12/30 09:38:47 angusgb Exp $
   //
   //
///////

#ifndef _htcheck_h_
#define _htcheck_h_

#ifdef HAVE_STD
#include <iostream>
#include <fstream>
#ifdef HAVE_NAMESPACES
using namespace std;
#endif
#else
#include <iostream.h>
#include <fstream.h>
#endif /* HAVE_STD */

#include <Configuration.h>
#include <List.h>
#include <StringList.h>
#include <StringMatch.h>
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <htconfig.h>
#include <HtmysqlDB.h>
#include "HtRegex.h"


extern Configuration config;     // For compatibility with htdig stuff
extern int debug;                // For compatibility with htdig stuff

#endif


